'''SocketTransport implements TCP socket interface for Transport.'''

import socket
from select import select
from transport import Transport

class SocketTransportClient(Transport):
    def __init__(self, device, *args, **kwargs):
        device = device.split(':')
        if len(device) < 2:
            device = ('0.0.0.0', int(device[0]))
        else:
            device = (device[0], int(device[1]))

        self.socket = None        
        super(SocketTransportClient, self).__init__(device, *args, **kwargs)
    
    def _open(self):
        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.socket.connect(self.device)
        self.filelike = self.socket.makefile()
        
    def _close(self):
        self.socket.close()
        self.socket = None
        self.filelike = None
    
    def ready_to_read(self):
        rlist, _, _ = select([self.socket], [], [], 0)
        return len(rlist) > 0        
    
    def _write(self, msg, protobuf_msg):
        self.socket.sendall(msg)
        
    def _read(self):
        try:
            (msg_type, datalen) = self._read_headers(self.filelike)
            return (msg_type, self.filelike.read(datalen))
        except socket.error:
            print "Failed to read from device"
            return None

class SocketTransport(Transport):
    def __init__(self, device, *args, **kwargs):
        device = device.split(':')
        if len(device) < 2:
            device = ('0.0.0.0', int(device[0]))
        else:
            device = (device[0], int(device[1]))

        self.socket = None
        self.client = None
        self.filelike = None

        super(SocketTransport, self).__init__(device, *args, **kwargs)
        
    def _open(self):
        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        #self.socket.setblocking(0)
        
        self.socket.bind(self.device)
        self.socket.listen(5)
        
    def _disconnect_client(self):
        print "Disconnecting client"
        if self.client != None:
            self.client.close()
            self.client = None
            self.filelike = None
    
    def _close(self):
        self._disconnect_client()
        self.socket.close()
        self.socket = None
        
    def ready_to_read(self):
        if self.filelike:
            # Connected
            rlist, _, _ = select([self.client], [], [], 0)
            return len(rlist) > 0
        else:
            # Waiting for connection
            rlist, _, _ = select([self.socket], [], [], 0)
            if len(rlist) > 0:
                (self.client, ipaddr) = self.socket.accept()
                print "Connected", ipaddr[0]
                self.filelike = self.client.makefile()
                return self.ready_to_read()
            return False
        
    def _write(self, msg, protobuf_msg):
        if self.filelike:
            # None on disconnected client
            
            try:
                self.filelike.write(msg)
                self.filelike.flush()
            except socket.error:
                print "Socket error"
                self._disconnect_client()
                
    def _read(self):
        try:
            (msg_type, datalen) = self._read_headers(self.filelike)
            return (msg_type, self.filelike.read(datalen))
        except Exception:
            print "Failed to read from device"
            self._disconnect_client()
            return None



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import types_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages.proto',
  package='',
  serialized_pb=_b('\n\x0emessages.proto\x1a\x0btypes.proto\"\x0c\n\nInitialize\"\r\n\x0bGetFeatures\"\xfe\x02\n\x08\x46\x65\x61tures\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x15\n\rmajor_version\x18\x02 \x01(\r\x12\x15\n\rminor_version\x18\x03 \x01(\r\x12\x15\n\rpatch_version\x18\x04 \x01(\r\x12\x17\n\x0f\x62ootloader_mode\x18\x05 \x01(\x08\x12\x11\n\tdevice_id\x18\x06 \x01(\t\x12\x16\n\x0epin_protection\x18\x07 \x01(\x08\x12\x1d\n\x15passphrase_protection\x18\x08 \x01(\x08\x12\x10\n\x08language\x18\t \x01(\t\x12\r\n\x05label\x18\n \x01(\t\x12\x18\n\x05\x63oins\x18\x0b \x03(\x0b\x32\t.CoinType\x12\x13\n\x0binitialized\x18\x0c \x01(\x08\x12\x10\n\x08revision\x18\r \x01(\x0c\x12\x17\n\x0f\x62ootloader_hash\x18\x0e \x01(\x0c\x12\x10\n\x08imported\x18\x0f \x01(\x08\x12\x12\n\npin_cached\x18\x10 \x01(\x08\x12\x19\n\x11passphrase_cached\x18\x11 \x01(\x08\"\x0e\n\x0c\x43learSession\"\\\n\rApplySettings\x12\x10\n\x08language\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x16\n\x0euse_passphrase\x18\x03 \x01(\x08\x12\x12\n\nhomescreen\x18\x04 \x01(\x0c\"\x1b\n\tChangePin\x12\x0e\n\x06remove\x18\x01 \x01(\x08\"i\n\x04Ping\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x19\n\x11\x62utton_protection\x18\x02 \x01(\x08\x12\x16\n\x0epin_protection\x18\x03 \x01(\x08\x12\x1d\n\x15passphrase_protection\x18\x04 \x01(\x08\"\x1a\n\x07Success\x12\x0f\n\x07message\x18\x01 \x01(\t\"6\n\x07\x46\x61ilure\x12\x1a\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x0c.FailureType\x12\x0f\n\x07message\x18\x02 \x01(\t\"?\n\rButtonRequest\x12 \n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.ButtonRequestType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\x0b\n\tButtonAck\"7\n\x10PinMatrixRequest\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.PinMatrixRequestType\"\x1b\n\x0cPinMatrixAck\x12\x0b\n\x03pin\x18\x01 \x02(\t\"\x08\n\x06\x43\x61ncel\"\x13\n\x11PassphraseRequest\"#\n\rPassphraseAck\x12\x12\n\npassphrase\x18\x01 \x02(\t\"\x1a\n\nGetEntropy\x12\x0c\n\x04size\x18\x01 \x02(\r\"\x1a\n\x07\x45ntropy\x12\x0f\n\x07\x65ntropy\x18\x01 \x02(\x0c\"Q\n\x0cGetPublicKey\x12\x11\n\taddress_n\x18\x01 \x03(\r\x12\x18\n\x10\x65\x63\x64sa_curve_name\x18\x02 \x01(\t\x12\x14\n\x0cshow_display\x18\x03 \x01(\x08\"4\n\tPublicKey\x12\x19\n\x04node\x18\x01 \x02(\x0b\x32\x0b.HDNodeType\x12\x0c\n\x04xpub\x18\x02 \x01(\t\"~\n\nGetAddress\x12\x11\n\taddress_n\x18\x01 \x03(\r\x12\x1a\n\tcoin_name\x18\x02 \x01(\t:\x07\x42itcoin\x12\x14\n\x0cshow_display\x18\x03 \x01(\x08\x12+\n\x08multisig\x18\x04 \x01(\x0b\x32\x19.MultisigRedeemScriptType\"\x1a\n\x07\x41\x64\x64ress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x02(\t\"\x0c\n\nWipeDevice\"\xa6\x01\n\nLoadDevice\x12\x10\n\x08mnemonic\x18\x01 \x01(\t\x12\x19\n\x04node\x18\x02 \x01(\x0b\x32\x0b.HDNodeType\x12\x0b\n\x03pin\x18\x03 \x01(\t\x12\x1d\n\x15passphrase_protection\x18\x04 \x01(\x08\x12\x19\n\x08language\x18\x05 \x01(\t:\x07\x65nglish\x12\r\n\x05label\x18\x06 \x01(\t\x12\x15\n\rskip_checksum\x18\x07 \x01(\x08\"\x9d\x01\n\x0bResetDevice\x12\x16\n\x0e\x64isplay_random\x18\x01 \x01(\x08\x12\x15\n\x08strength\x18\x02 \x01(\r:\x03\x32\x35\x36\x12\x1d\n\x15passphrase_protection\x18\x03 \x01(\x08\x12\x16\n\x0epin_protection\x18\x04 \x01(\x08\x12\x19\n\x08language\x18\x05 \x01(\t:\x07\x65nglish\x12\r\n\x05label\x18\x06 \x01(\t\"\x10\n\x0e\x45ntropyRequest\"\x1d\n\nEntropyAck\x12\x0f\n\x07\x65ntropy\x18\x01 \x01(\x0c\"\x9f\x01\n\x0eRecoveryDevice\x12\x12\n\nword_count\x18\x01 \x01(\r\x12\x1d\n\x15passphrase_protection\x18\x02 \x01(\x08\x12\x16\n\x0epin_protection\x18\x03 \x01(\x08\x12\x19\n\x08language\x18\x04 \x01(\t:\x07\x65nglish\x12\r\n\x05label\x18\x05 \x01(\t\x12\x18\n\x10\x65nforce_wordlist\x18\x06 \x01(\x08\"\r\n\x0bWordRequest\"\x17\n\x07WordAck\x12\x0c\n\x04word\x18\x01 \x02(\t\"M\n\x0bSignMessage\x12\x11\n\taddress_n\x18\x01 \x03(\r\x12\x0f\n\x07message\x18\x02 \x02(\x0c\x12\x1a\n\tcoin_name\x18\x03 \x01(\t:\x07\x42itcoin\"D\n\rVerifyMessage\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"6\n\x10MessageSignature\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"v\n\x0e\x45ncryptMessage\x12\x0e\n\x06pubkey\x18\x01 \x01(\x0c\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x12\x14\n\x0c\x64isplay_only\x18\x03 \x01(\x08\x12\x11\n\taddress_n\x18\x04 \x03(\r\x12\x1a\n\tcoin_name\x18\x05 \x01(\t:\x07\x42itcoin\"@\n\x10\x45ncryptedMessage\x12\r\n\x05nonce\x18\x01 \x01(\x0c\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x12\x0c\n\x04hmac\x18\x03 \x01(\x0c\"Q\n\x0e\x44\x65\x63ryptMessage\x12\x11\n\taddress_n\x18\x01 \x03(\r\x12\r\n\x05nonce\x18\x02 \x01(\x0c\x12\x0f\n\x07message\x18\x03 \x01(\x0c\x12\x0c\n\x04hmac\x18\x04 \x01(\x0c\"4\n\x10\x44\x65\x63ryptedMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\x8c\x01\n\x0e\x43ipherKeyValue\x12\x11\n\taddress_n\x18\x01 \x03(\r\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x0c\x12\x0f\n\x07\x65ncrypt\x18\x04 \x01(\x08\x12\x16\n\x0e\x61sk_on_encrypt\x18\x05 \x01(\x08\x12\x16\n\x0e\x61sk_on_decrypt\x18\x06 \x01(\x08\x12\n\n\x02iv\x18\x07 \x01(\x0c\"!\n\x10\x43ipheredKeyValue\x12\r\n\x05value\x18\x01 \x01(\x0c\"Y\n\x0e\x45stimateTxSize\x12\x15\n\routputs_count\x18\x01 \x02(\r\x12\x14\n\x0cinputs_count\x18\x02 \x02(\r\x12\x1a\n\tcoin_name\x18\x03 \x01(\t:\x07\x42itcoin\"\x19\n\x06TxSize\x12\x0f\n\x07tx_size\x18\x01 \x01(\r\"Q\n\x06SignTx\x12\x15\n\routputs_count\x18\x01 \x02(\r\x12\x14\n\x0cinputs_count\x18\x02 \x02(\r\x12\x1a\n\tcoin_name\x18\x03 \x01(\t:\x07\x42itcoin\"\x90\x01\n\x0cSimpleSignTx\x12\x1c\n\x06inputs\x18\x01 \x03(\x0b\x32\x0c.TxInputType\x12\x1e\n\x07outputs\x18\x02 \x03(\x0b\x32\r.TxOutputType\x12&\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x10.TransactionType\x12\x1a\n\tcoin_name\x18\x04 \x01(\t:\x07\x42itcoin\"\x85\x01\n\tTxRequest\x12\"\n\x0crequest_type\x18\x01 \x01(\x0e\x32\x0c.RequestType\x12&\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x15.TxRequestDetailsType\x12,\n\nserialized\x18\x03 \x01(\x0b\x32\x18.TxRequestSerializedType\"%\n\x05TxAck\x12\x1c\n\x02tx\x18\x01 \x01(\x0b\x32\x10.TransactionType\"}\n\x0cSignIdentity\x12\x1f\n\x08identity\x18\x01 \x01(\x0b\x32\r.IdentityType\x12\x18\n\x10\x63hallenge_hidden\x18\x02 \x01(\x0c\x12\x18\n\x10\x63hallenge_visual\x18\x03 \x01(\t\x12\x18\n\x10\x65\x63\x64sa_curve_name\x18\x04 \x01(\t\"H\n\x0eSignedIdentity\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"\x0f\n\rFirmwareErase\"!\n\x0e\x46irmwareUpload\x12\x0f\n\x07payload\x18\x01 \x02(\x0c\"#\n\x11\x44\x65\x62ugLinkDecision\x12\x0e\n\x06yes_no\x18\x01 \x02(\x08\"\x13\n\x11\x44\x65\x62ugLinkGetState\"\xeb\x01\n\x0e\x44\x65\x62ugLinkState\x12\x0e\n\x06layout\x18\x01 \x01(\x0c\x12\x0b\n\x03pin\x18\x02 \x01(\t\x12\x0e\n\x06matrix\x18\x03 \x01(\t\x12\x10\n\x08mnemonic\x18\x04 \x01(\t\x12\x19\n\x04node\x18\x05 \x01(\x0b\x32\x0b.HDNodeType\x12\x1d\n\x15passphrase_protection\x18\x06 \x01(\x08\x12\x12\n\nreset_word\x18\x07 \x01(\t\x12\x15\n\rreset_entropy\x18\x08 \x01(\x0c\x12\x1a\n\x12recovery_fake_word\x18\t \x01(\t\x12\x19\n\x11recovery_word_pos\x18\n \x01(\r\"\x0f\n\rDebugLinkStop\";\n\x0c\x44\x65\x62ugLinkLog\x12\r\n\x05level\x18\x01 \x01(\r\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t*\x86\x0f\n\x0bMessageType\x12 \n\x16MessageType_Initialize\x10\x00\x1a\x04\x90\xb5\x18\x01\x12\x1a\n\x10MessageType_Ping\x10\x01\x1a\x04\x90\xb5\x18\x01\x12\x1d\n\x13MessageType_Success\x10\x02\x1a\x04\x98\xb5\x18\x01\x12\x1d\n\x13MessageType_Failure\x10\x03\x1a\x04\x98\xb5\x18\x01\x12\x1f\n\x15MessageType_ChangePin\x10\x04\x1a\x04\x90\xb5\x18\x01\x12 \n\x16MessageType_WipeDevice\x10\x05\x1a\x04\x90\xb5\x18\x01\x12#\n\x19MessageType_FirmwareErase\x10\x06\x1a\x04\x90\xb5\x18\x01\x12$\n\x1aMessageType_FirmwareUpload\x10\x07\x1a\x04\x90\xb5\x18\x01\x12 \n\x16MessageType_GetEntropy\x10\t\x1a\x04\x90\xb5\x18\x01\x12\x1d\n\x13MessageType_Entropy\x10\n\x1a\x04\x98\xb5\x18\x01\x12\"\n\x18MessageType_GetPublicKey\x10\x0b\x1a\x04\x90\xb5\x18\x01\x12\x1f\n\x15MessageType_PublicKey\x10\x0c\x1a\x04\x98\xb5\x18\x01\x12 \n\x16MessageType_LoadDevice\x10\r\x1a\x04\x90\xb5\x18\x01\x12!\n\x17MessageType_ResetDevice\x10\x0e\x1a\x04\x90\xb5\x18\x01\x12\x1c\n\x12MessageType_SignTx\x10\x0f\x1a\x04\x90\xb5\x18\x01\x12\"\n\x18MessageType_SimpleSignTx\x10\x10\x1a\x04\x90\xb5\x18\x01\x12\x1e\n\x14MessageType_Features\x10\x11\x1a\x04\x98\xb5\x18\x01\x12&\n\x1cMessageType_PinMatrixRequest\x10\x12\x1a\x04\x98\xb5\x18\x01\x12\"\n\x18MessageType_PinMatrixAck\x10\x13\x1a\x04\x90\xb5\x18\x01\x12\x1c\n\x12MessageType_Cancel\x10\x14\x1a\x04\x90\xb5\x18\x01\x12\x1f\n\x15MessageType_TxRequest\x10\x15\x1a\x04\x98\xb5\x18\x01\x12\x1b\n\x11MessageType_TxAck\x10\x16\x1a\x04\x90\xb5\x18\x01\x12$\n\x1aMessageType_CipherKeyValue\x10\x17\x1a\x04\x90\xb5\x18\x01\x12\"\n\x18MessageType_ClearSession\x10\x18\x1a\x04\x90\xb5\x18\x01\x12#\n\x19MessageType_ApplySettings\x10\x19\x1a\x04\x90\xb5\x18\x01\x12#\n\x19MessageType_ButtonRequest\x10\x1a\x1a\x04\x98\xb5\x18\x01\x12\x1f\n\x15MessageType_ButtonAck\x10\x1b\x1a\x04\x90\xb5\x18\x01\x12 \n\x16MessageType_GetAddress\x10\x1d\x1a\x04\x90\xb5\x18\x01\x12\x1d\n\x13MessageType_Address\x10\x1e\x1a\x04\x98\xb5\x18\x01\x12$\n\x1aMessageType_EntropyRequest\x10#\x1a\x04\x98\xb5\x18\x01\x12 \n\x16MessageType_EntropyAck\x10$\x1a\x04\x90\xb5\x18\x01\x12!\n\x17MessageType_SignMessage\x10&\x1a\x04\x90\xb5\x18\x01\x12#\n\x19MessageType_VerifyMessage\x10\'\x1a\x04\x90\xb5\x18\x01\x12&\n\x1cMessageType_MessageSignature\x10(\x1a\x04\x98\xb5\x18\x01\x12\'\n\x1dMessageType_PassphraseRequest\x10)\x1a\x04\x98\xb5\x18\x01\x12#\n\x19MessageType_PassphraseAck\x10*\x1a\x04\x90\xb5\x18\x01\x12$\n\x1aMessageType_EstimateTxSize\x10+\x1a\x04\x90\xb5\x18\x01\x12\x1c\n\x12MessageType_TxSize\x10,\x1a\x04\x98\xb5\x18\x01\x12$\n\x1aMessageType_RecoveryDevice\x10-\x1a\x04\x90\xb5\x18\x01\x12!\n\x17MessageType_WordRequest\x10.\x1a\x04\x98\xb5\x18\x01\x12\x1d\n\x13MessageType_WordAck\x10/\x1a\x04\x90\xb5\x18\x01\x12&\n\x1cMessageType_CipheredKeyValue\x10\x30\x1a\x04\x98\xb5\x18\x01\x12$\n\x1aMessageType_EncryptMessage\x10\x31\x1a\x04\x90\xb5\x18\x01\x12&\n\x1cMessageType_EncryptedMessage\x10\x32\x1a\x04\x98\xb5\x18\x01\x12$\n\x1aMessageType_DecryptMessage\x10\x33\x1a\x04\x90\xb5\x18\x01\x12&\n\x1cMessageType_DecryptedMessage\x10\x34\x1a\x04\x98\xb5\x18\x01\x12\"\n\x18MessageType_SignIdentity\x10\x35\x1a\x04\x90\xb5\x18\x01\x12$\n\x1aMessageType_SignedIdentity\x10\x36\x1a\x04\x98\xb5\x18\x01\x12!\n\x17MessageType_GetFeatures\x10\x37\x1a\x04\x90\xb5\x18\x01\x12\'\n\x1dMessageType_DebugLinkDecision\x10\x64\x1a\x04\xa0\xb5\x18\x01\x12\'\n\x1dMessageType_DebugLinkGetState\x10\x65\x1a\x04\xa0\xb5\x18\x01\x12$\n\x1aMessageType_DebugLinkState\x10\x66\x1a\x04\xa8\xb5\x18\x01\x12#\n\x19MessageType_DebugLinkStop\x10g\x1a\x04\xa0\xb5\x18\x01\x12\"\n\x18MessageType_DebugLinkLog\x10h\x1a\x04\xa8\xb5\x18\x01\x42\x30\n\x1f\x63om.satoshilabs.trezor.protobufB\rTrezorMessage')
  ,
  dependencies=[types_pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MessageType_Initialize', index=0, number=0,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Ping', index=1, number=1,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Success', index=2, number=2,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Failure', index=3, number=3,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_ChangePin', index=4, number=4,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_WipeDevice', index=5, number=5,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_FirmwareErase', index=6, number=6,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_FirmwareUpload', index=7, number=7,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_GetEntropy', index=8, number=9,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Entropy', index=9, number=10,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_GetPublicKey', index=10, number=11,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_PublicKey', index=11, number=12,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_LoadDevice', index=12, number=13,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_ResetDevice', index=13, number=14,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_SignTx', index=14, number=15,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_SimpleSignTx', index=15, number=16,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Features', index=16, number=17,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_PinMatrixRequest', index=17, number=18,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_PinMatrixAck', index=18, number=19,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Cancel', index=19, number=20,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_TxRequest', index=20, number=21,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_TxAck', index=21, number=22,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_CipherKeyValue', index=22, number=23,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_ClearSession', index=23, number=24,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_ApplySettings', index=24, number=25,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_ButtonRequest', index=25, number=26,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_ButtonAck', index=26, number=27,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_GetAddress', index=27, number=29,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_Address', index=28, number=30,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_EntropyRequest', index=29, number=35,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_EntropyAck', index=30, number=36,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_SignMessage', index=31, number=38,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_VerifyMessage', index=32, number=39,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_MessageSignature', index=33, number=40,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_PassphraseRequest', index=34, number=41,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_PassphraseAck', index=35, number=42,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_EstimateTxSize', index=36, number=43,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_TxSize', index=37, number=44,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_RecoveryDevice', index=38, number=45,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_WordRequest', index=39, number=46,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_WordAck', index=40, number=47,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_CipheredKeyValue', index=41, number=48,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_EncryptMessage', index=42, number=49,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_EncryptedMessage', index=43, number=50,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DecryptMessage', index=44, number=51,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DecryptedMessage', index=45, number=52,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_SignIdentity', index=46, number=53,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_SignedIdentity', index=47, number=54,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_GetFeatures', index=48, number=55,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DebugLinkDecision', index=49, number=100,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\240\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DebugLinkGetState', index=50, number=101,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\240\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DebugLinkState', index=51, number=102,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\250\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DebugLinkStop', index=52, number=103,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\240\265\030\001')),
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MessageType_DebugLinkLog', index=53, number=104,
      options=_descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\250\265\030\001')),
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3807,
  serialized_end=5733,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
MessageType_Initialize = 0
MessageType_Ping = 1
MessageType_Success = 2
MessageType_Failure = 3
MessageType_ChangePin = 4
MessageType_WipeDevice = 5
MessageType_FirmwareErase = 6
MessageType_FirmwareUpload = 7
MessageType_GetEntropy = 9
MessageType_Entropy = 10
MessageType_GetPublicKey = 11
MessageType_PublicKey = 12
MessageType_LoadDevice = 13
MessageType_ResetDevice = 14
MessageType_SignTx = 15
MessageType_SimpleSignTx = 16
MessageType_Features = 17
MessageType_PinMatrixRequest = 18
MessageType_PinMatrixAck = 19
MessageType_Cancel = 20
MessageType_TxRequest = 21
MessageType_TxAck = 22
MessageType_CipherKeyValue = 23
MessageType_ClearSession = 24
MessageType_ApplySettings = 25
MessageType_ButtonRequest = 26
MessageType_ButtonAck = 27
MessageType_GetAddress = 29
MessageType_Address = 30
MessageType_EntropyRequest = 35
MessageType_EntropyAck = 36
MessageType_SignMessage = 38
MessageType_VerifyMessage = 39
MessageType_MessageSignature = 40
MessageType_PassphraseRequest = 41
MessageType_PassphraseAck = 42
MessageType_EstimateTxSize = 43
MessageType_TxSize = 44
MessageType_RecoveryDevice = 45
MessageType_WordRequest = 46
MessageType_WordAck = 47
MessageType_CipheredKeyValue = 48
MessageType_EncryptMessage = 49
MessageType_EncryptedMessage = 50
MessageType_DecryptMessage = 51
MessageType_DecryptedMessage = 52
MessageType_SignIdentity = 53
MessageType_SignedIdentity = 54
MessageType_GetFeatures = 55
MessageType_DebugLinkDecision = 100
MessageType_DebugLinkGetState = 101
MessageType_DebugLinkState = 102
MessageType_DebugLinkStop = 103
MessageType_DebugLinkLog = 104



_INITIALIZE = _descriptor.Descriptor(
  name='Initialize',
  full_name='Initialize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=43,
)


_GETFEATURES = _descriptor.Descriptor(
  name='GetFeatures',
  full_name='GetFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=58,
)


_FEATURES = _descriptor.Descriptor(
  name='Features',
  full_name='Features',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='Features.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='major_version', full_name='Features.major_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minor_version', full_name='Features.minor_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='patch_version', full_name='Features.patch_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootloader_mode', full_name='Features.bootloader_mode', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='Features.device_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_protection', full_name='Features.pin_protection', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_protection', full_name='Features.passphrase_protection', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='Features.language', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label', full_name='Features.label', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coins', full_name='Features.coins', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initialized', full_name='Features.initialized', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revision', full_name='Features.revision', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootloader_hash', full_name='Features.bootloader_hash', index=13,
      number=14, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='imported', full_name='Features.imported', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_cached', full_name='Features.pin_cached', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_cached', full_name='Features.passphrase_cached', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=443,
)


_CLEARSESSION = _descriptor.Descriptor(
  name='ClearSession',
  full_name='ClearSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=459,
)


_APPLYSETTINGS = _descriptor.Descriptor(
  name='ApplySettings',
  full_name='ApplySettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='ApplySettings.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label', full_name='ApplySettings.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_passphrase', full_name='ApplySettings.use_passphrase', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='homescreen', full_name='ApplySettings.homescreen', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=553,
)


_CHANGEPIN = _descriptor.Descriptor(
  name='ChangePin',
  full_name='ChangePin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='remove', full_name='ChangePin.remove', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=582,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='Ping.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='button_protection', full_name='Ping.button_protection', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_protection', full_name='Ping.pin_protection', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_protection', full_name='Ping.passphrase_protection', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=689,
)


_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='Success.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=717,
)


_FAILURE = _descriptor.Descriptor(
  name='Failure',
  full_name='Failure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Failure.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='Failure.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=773,
)


_BUTTONREQUEST = _descriptor.Descriptor(
  name='ButtonRequest',
  full_name='ButtonRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='ButtonRequest.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='ButtonRequest.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=838,
)


_BUTTONACK = _descriptor.Descriptor(
  name='ButtonAck',
  full_name='ButtonAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=851,
)


_PINMATRIXREQUEST = _descriptor.Descriptor(
  name='PinMatrixRequest',
  full_name='PinMatrixRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='PinMatrixRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=908,
)


_PINMATRIXACK = _descriptor.Descriptor(
  name='PinMatrixAck',
  full_name='PinMatrixAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='PinMatrixAck.pin', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=937,
)


_CANCEL = _descriptor.Descriptor(
  name='Cancel',
  full_name='Cancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=947,
)


_PASSPHRASEREQUEST = _descriptor.Descriptor(
  name='PassphraseRequest',
  full_name='PassphraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=968,
)


_PASSPHRASEACK = _descriptor.Descriptor(
  name='PassphraseAck',
  full_name='PassphraseAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='passphrase', full_name='PassphraseAck.passphrase', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1005,
)


_GETENTROPY = _descriptor.Descriptor(
  name='GetEntropy',
  full_name='GetEntropy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='GetEntropy.size', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1033,
)


_ENTROPY = _descriptor.Descriptor(
  name='Entropy',
  full_name='Entropy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entropy', full_name='Entropy.entropy', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1061,
)


_GETPUBLICKEY = _descriptor.Descriptor(
  name='GetPublicKey',
  full_name='GetPublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_n', full_name='GetPublicKey.address_n', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ecdsa_curve_name', full_name='GetPublicKey.ecdsa_curve_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='show_display', full_name='GetPublicKey.show_display', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1063,
  serialized_end=1144,
)


_PUBLICKEY = _descriptor.Descriptor(
  name='PublicKey',
  full_name='PublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='PublicKey.node', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xpub', full_name='PublicKey.xpub', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1146,
  serialized_end=1198,
)


_GETADDRESS = _descriptor.Descriptor(
  name='GetAddress',
  full_name='GetAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_n', full_name='GetAddress.address_n', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_name', full_name='GetAddress.coin_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("Bitcoin").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='show_display', full_name='GetAddress.show_display', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='multisig', full_name='GetAddress.multisig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1200,
  serialized_end=1326,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='Address.address', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1328,
  serialized_end=1354,
)


_WIPEDEVICE = _descriptor.Descriptor(
  name='WipeDevice',
  full_name='WipeDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1356,
  serialized_end=1368,
)


_LOADDEVICE = _descriptor.Descriptor(
  name='LoadDevice',
  full_name='LoadDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mnemonic', full_name='LoadDevice.mnemonic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node', full_name='LoadDevice.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='LoadDevice.pin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_protection', full_name='LoadDevice.passphrase_protection', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='LoadDevice.language', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("english").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label', full_name='LoadDevice.label', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skip_checksum', full_name='LoadDevice.skip_checksum', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1537,
)


_RESETDEVICE = _descriptor.Descriptor(
  name='ResetDevice',
  full_name='ResetDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='display_random', full_name='ResetDevice.display_random', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strength', full_name='ResetDevice.strength', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=256,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_protection', full_name='ResetDevice.passphrase_protection', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_protection', full_name='ResetDevice.pin_protection', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='ResetDevice.language', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("english").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label', full_name='ResetDevice.label', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1540,
  serialized_end=1697,
)


_ENTROPYREQUEST = _descriptor.Descriptor(
  name='EntropyRequest',
  full_name='EntropyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1699,
  serialized_end=1715,
)


_ENTROPYACK = _descriptor.Descriptor(
  name='EntropyAck',
  full_name='EntropyAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entropy', full_name='EntropyAck.entropy', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1717,
  serialized_end=1746,
)


_RECOVERYDEVICE = _descriptor.Descriptor(
  name='RecoveryDevice',
  full_name='RecoveryDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word_count', full_name='RecoveryDevice.word_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_protection', full_name='RecoveryDevice.passphrase_protection', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin_protection', full_name='RecoveryDevice.pin_protection', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='RecoveryDevice.language', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("english").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label', full_name='RecoveryDevice.label', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enforce_wordlist', full_name='RecoveryDevice.enforce_wordlist', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1749,
  serialized_end=1908,
)


_WORDREQUEST = _descriptor.Descriptor(
  name='WordRequest',
  full_name='WordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1910,
  serialized_end=1923,
)


_WORDACK = _descriptor.Descriptor(
  name='WordAck',
  full_name='WordAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word', full_name='WordAck.word', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=1948,
)


_SIGNMESSAGE = _descriptor.Descriptor(
  name='SignMessage',
  full_name='SignMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_n', full_name='SignMessage.address_n', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='SignMessage.message', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_name', full_name='SignMessage.coin_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("Bitcoin").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1950,
  serialized_end=2027,
)


_VERIFYMESSAGE = _descriptor.Descriptor(
  name='VerifyMessage',
  full_name='VerifyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='VerifyMessage.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signature', full_name='VerifyMessage.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='VerifyMessage.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2029,
  serialized_end=2097,
)


_MESSAGESIGNATURE = _descriptor.Descriptor(
  name='MessageSignature',
  full_name='MessageSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='MessageSignature.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signature', full_name='MessageSignature.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2099,
  serialized_end=2153,
)


_ENCRYPTMESSAGE = _descriptor.Descriptor(
  name='EncryptMessage',
  full_name='EncryptMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubkey', full_name='EncryptMessage.pubkey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='EncryptMessage.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='display_only', full_name='EncryptMessage.display_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='address_n', full_name='EncryptMessage.address_n', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_name', full_name='EncryptMessage.coin_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("Bitcoin").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2273,
)


_ENCRYPTEDMESSAGE = _descriptor.Descriptor(
  name='EncryptedMessage',
  full_name='EncryptedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='EncryptedMessage.nonce', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='EncryptedMessage.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hmac', full_name='EncryptedMessage.hmac', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2339,
)


_DECRYPTMESSAGE = _descriptor.Descriptor(
  name='DecryptMessage',
  full_name='DecryptMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_n', full_name='DecryptMessage.address_n', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='DecryptMessage.nonce', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='DecryptMessage.message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hmac', full_name='DecryptMessage.hmac', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2341,
  serialized_end=2422,
)


_DECRYPTEDMESSAGE = _descriptor.Descriptor(
  name='DecryptedMessage',
  full_name='DecryptedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='DecryptedMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='address', full_name='DecryptedMessage.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2424,
  serialized_end=2476,
)


_CIPHERKEYVALUE = _descriptor.Descriptor(
  name='CipherKeyValue',
  full_name='CipherKeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_n', full_name='CipherKeyValue.address_n', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='CipherKeyValue.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CipherKeyValue.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encrypt', full_name='CipherKeyValue.encrypt', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ask_on_encrypt', full_name='CipherKeyValue.ask_on_encrypt', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ask_on_decrypt', full_name='CipherKeyValue.ask_on_decrypt', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='iv', full_name='CipherKeyValue.iv', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2479,
  serialized_end=2619,
)


_CIPHEREDKEYVALUE = _descriptor.Descriptor(
  name='CipheredKeyValue',
  full_name='CipheredKeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='CipheredKeyValue.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2621,
  serialized_end=2654,
)


_ESTIMATETXSIZE = _descriptor.Descriptor(
  name='EstimateTxSize',
  full_name='EstimateTxSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs_count', full_name='EstimateTxSize.outputs_count', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inputs_count', full_name='EstimateTxSize.inputs_count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_name', full_name='EstimateTxSize.coin_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("Bitcoin").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2656,
  serialized_end=2745,
)


_TXSIZE = _descriptor.Descriptor(
  name='TxSize',
  full_name='TxSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_size', full_name='TxSize.tx_size', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2747,
  serialized_end=2772,
)


_SIGNTX = _descriptor.Descriptor(
  name='SignTx',
  full_name='SignTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs_count', full_name='SignTx.outputs_count', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inputs_count', full_name='SignTx.inputs_count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_name', full_name='SignTx.coin_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("Bitcoin").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2774,
  serialized_end=2855,
)


_SIMPLESIGNTX = _descriptor.Descriptor(
  name='SimpleSignTx',
  full_name='SimpleSignTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='SimpleSignTx.inputs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='SimpleSignTx.outputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='SimpleSignTx.transactions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_name', full_name='SimpleSignTx.coin_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=_b("Bitcoin").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2858,
  serialized_end=3002,
)


_TXREQUEST = _descriptor.Descriptor(
  name='TxRequest',
  full_name='TxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_type', full_name='TxRequest.request_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details', full_name='TxRequest.details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serialized', full_name='TxRequest.serialized', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3005,
  serialized_end=3138,
)


_TXACK = _descriptor.Descriptor(
  name='TxAck',
  full_name='TxAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='TxAck.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3140,
  serialized_end=3177,
)


_SIGNIDENTITY = _descriptor.Descriptor(
  name='SignIdentity',
  full_name='SignIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='SignIdentity.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_hidden', full_name='SignIdentity.challenge_hidden', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='challenge_visual', full_name='SignIdentity.challenge_visual', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ecdsa_curve_name', full_name='SignIdentity.ecdsa_curve_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3179,
  serialized_end=3304,
)


_SIGNEDIDENTITY = _descriptor.Descriptor(
  name='SignedIdentity',
  full_name='SignedIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='SignedIdentity.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='SignedIdentity.public_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signature', full_name='SignedIdentity.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3306,
  serialized_end=3378,
)


_FIRMWAREERASE = _descriptor.Descriptor(
  name='FirmwareErase',
  full_name='FirmwareErase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3380,
  serialized_end=3395,
)


_FIRMWAREUPLOAD = _descriptor.Descriptor(
  name='FirmwareUpload',
  full_name='FirmwareUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='FirmwareUpload.payload', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3397,
  serialized_end=3430,
)


_DEBUGLINKDECISION = _descriptor.Descriptor(
  name='DebugLinkDecision',
  full_name='DebugLinkDecision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yes_no', full_name='DebugLinkDecision.yes_no', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3432,
  serialized_end=3467,
)


_DEBUGLINKGETSTATE = _descriptor.Descriptor(
  name='DebugLinkGetState',
  full_name='DebugLinkGetState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3469,
  serialized_end=3488,
)


_DEBUGLINKSTATE = _descriptor.Descriptor(
  name='DebugLinkState',
  full_name='DebugLinkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='layout', full_name='DebugLinkState.layout', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='DebugLinkState.pin', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matrix', full_name='DebugLinkState.matrix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mnemonic', full_name='DebugLinkState.mnemonic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node', full_name='DebugLinkState.node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passphrase_protection', full_name='DebugLinkState.passphrase_protection', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reset_word', full_name='DebugLinkState.reset_word', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reset_entropy', full_name='DebugLinkState.reset_entropy', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recovery_fake_word', full_name='DebugLinkState.recovery_fake_word', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recovery_word_pos', full_name='DebugLinkState.recovery_word_pos', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3491,
  serialized_end=3726,
)


_DEBUGLINKSTOP = _descriptor.Descriptor(
  name='DebugLinkStop',
  full_name='DebugLinkStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3728,
  serialized_end=3743,
)


_DEBUGLINKLOG = _descriptor.Descriptor(
  name='DebugLinkLog',
  full_name='DebugLinkLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='DebugLinkLog.level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='DebugLinkLog.bucket', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='DebugLinkLog.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3745,
  serialized_end=3804,
)

_FEATURES.fields_by_name['coins'].message_type = types_pb2._COINTYPE
_FAILURE.fields_by_name['code'].enum_type = types_pb2._FAILURETYPE
_BUTTONREQUEST.fields_by_name['code'].enum_type = types_pb2._BUTTONREQUESTTYPE
_PINMATRIXREQUEST.fields_by_name['type'].enum_type = types_pb2._PINMATRIXREQUESTTYPE
_PUBLICKEY.fields_by_name['node'].message_type = types_pb2._HDNODETYPE
_GETADDRESS.fields_by_name['multisig'].message_type = types_pb2._MULTISIGREDEEMSCRIPTTYPE
_LOADDEVICE.fields_by_name['node'].message_type = types_pb2._HDNODETYPE
_SIMPLESIGNTX.fields_by_name['inputs'].message_type = types_pb2._TXINPUTTYPE
_SIMPLESIGNTX.fields_by_name['outputs'].message_type = types_pb2._TXOUTPUTTYPE
_SIMPLESIGNTX.fields_by_name['transactions'].message_type = types_pb2._TRANSACTIONTYPE
_TXREQUEST.fields_by_name['request_type'].enum_type = types_pb2._REQUESTTYPE
_TXREQUEST.fields_by_name['details'].message_type = types_pb2._TXREQUESTDETAILSTYPE
_TXREQUEST.fields_by_name['serialized'].message_type = types_pb2._TXREQUESTSERIALIZEDTYPE
_TXACK.fields_by_name['tx'].message_type = types_pb2._TRANSACTIONTYPE
_SIGNIDENTITY.fields_by_name['identity'].message_type = types_pb2._IDENTITYTYPE
_DEBUGLINKSTATE.fields_by_name['node'].message_type = types_pb2._HDNODETYPE
DESCRIPTOR.message_types_by_name['Initialize'] = _INITIALIZE
DESCRIPTOR.message_types_by_name['GetFeatures'] = _GETFEATURES
DESCRIPTOR.message_types_by_name['Features'] = _FEATURES
DESCRIPTOR.message_types_by_name['ClearSession'] = _CLEARSESSION
DESCRIPTOR.message_types_by_name['ApplySettings'] = _APPLYSETTINGS
DESCRIPTOR.message_types_by_name['ChangePin'] = _CHANGEPIN
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Success'] = _SUCCESS
DESCRIPTOR.message_types_by_name['Failure'] = _FAILURE
DESCRIPTOR.message_types_by_name['ButtonRequest'] = _BUTTONREQUEST
DESCRIPTOR.message_types_by_name['ButtonAck'] = _BUTTONACK
DESCRIPTOR.message_types_by_name['PinMatrixRequest'] = _PINMATRIXREQUEST
DESCRIPTOR.message_types_by_name['PinMatrixAck'] = _PINMATRIXACK
DESCRIPTOR.message_types_by_name['Cancel'] = _CANCEL
DESCRIPTOR.message_types_by_name['PassphraseRequest'] = _PASSPHRASEREQUEST
DESCRIPTOR.message_types_by_name['PassphraseAck'] = _PASSPHRASEACK
DESCRIPTOR.message_types_by_name['GetEntropy'] = _GETENTROPY
DESCRIPTOR.message_types_by_name['Entropy'] = _ENTROPY
DESCRIPTOR.message_types_by_name['GetPublicKey'] = _GETPUBLICKEY
DESCRIPTOR.message_types_by_name['PublicKey'] = _PUBLICKEY
DESCRIPTOR.message_types_by_name['GetAddress'] = _GETADDRESS
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['WipeDevice'] = _WIPEDEVICE
DESCRIPTOR.message_types_by_name['LoadDevice'] = _LOADDEVICE
DESCRIPTOR.message_types_by_name['ResetDevice'] = _RESETDEVICE
DESCRIPTOR.message_types_by_name['EntropyRequest'] = _ENTROPYREQUEST
DESCRIPTOR.message_types_by_name['EntropyAck'] = _ENTROPYACK
DESCRIPTOR.message_types_by_name['RecoveryDevice'] = _RECOVERYDEVICE
DESCRIPTOR.message_types_by_name['WordRequest'] = _WORDREQUEST
DESCRIPTOR.message_types_by_name['WordAck'] = _WORDACK
DESCRIPTOR.message_types_by_name['SignMessage'] = _SIGNMESSAGE
DESCRIPTOR.message_types_by_name['VerifyMessage'] = _VERIFYMESSAGE
DESCRIPTOR.message_types_by_name['MessageSignature'] = _MESSAGESIGNATURE
DESCRIPTOR.message_types_by_name['EncryptMessage'] = _ENCRYPTMESSAGE
DESCRIPTOR.message_types_by_name['EncryptedMessage'] = _ENCRYPTEDMESSAGE
DESCRIPTOR.message_types_by_name['DecryptMessage'] = _DECRYPTMESSAGE
DESCRIPTOR.message_types_by_name['DecryptedMessage'] = _DECRYPTEDMESSAGE
DESCRIPTOR.message_types_by_name['CipherKeyValue'] = _CIPHERKEYVALUE
DESCRIPTOR.message_types_by_name['CipheredKeyValue'] = _CIPHEREDKEYVALUE
DESCRIPTOR.message_types_by_name['EstimateTxSize'] = _ESTIMATETXSIZE
DESCRIPTOR.message_types_by_name['TxSize'] = _TXSIZE
DESCRIPTOR.message_types_by_name['SignTx'] = _SIGNTX
DESCRIPTOR.message_types_by_name['SimpleSignTx'] = _SIMPLESIGNTX
DESCRIPTOR.message_types_by_name['TxRequest'] = _TXREQUEST
DESCRIPTOR.message_types_by_name['TxAck'] = _TXACK
DESCRIPTOR.message_types_by_name['SignIdentity'] = _SIGNIDENTITY
DESCRIPTOR.message_types_by_name['SignedIdentity'] = _SIGNEDIDENTITY
DESCRIPTOR.message_types_by_name['FirmwareErase'] = _FIRMWAREERASE
DESCRIPTOR.message_types_by_name['FirmwareUpload'] = _FIRMWAREUPLOAD
DESCRIPTOR.message_types_by_name['DebugLinkDecision'] = _DEBUGLINKDECISION
DESCRIPTOR.message_types_by_name['DebugLinkGetState'] = _DEBUGLINKGETSTATE
DESCRIPTOR.message_types_by_name['DebugLinkState'] = _DEBUGLINKSTATE
DESCRIPTOR.message_types_by_name['DebugLinkStop'] = _DEBUGLINKSTOP
DESCRIPTOR.message_types_by_name['DebugLinkLog'] = _DEBUGLINKLOG
DESCRIPTOR.enum_types_by_name['MessageType'] = _MESSAGETYPE

Initialize = _reflection.GeneratedProtocolMessageType('Initialize', (_message.Message,), dict(
  DESCRIPTOR = _INITIALIZE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Initialize)
  ))
_sym_db.RegisterMessage(Initialize)

GetFeatures = _reflection.GeneratedProtocolMessageType('GetFeatures', (_message.Message,), dict(
  DESCRIPTOR = _GETFEATURES,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:GetFeatures)
  ))
_sym_db.RegisterMessage(GetFeatures)

Features = _reflection.GeneratedProtocolMessageType('Features', (_message.Message,), dict(
  DESCRIPTOR = _FEATURES,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Features)
  ))
_sym_db.RegisterMessage(Features)

ClearSession = _reflection.GeneratedProtocolMessageType('ClearSession', (_message.Message,), dict(
  DESCRIPTOR = _CLEARSESSION,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ClearSession)
  ))
_sym_db.RegisterMessage(ClearSession)

ApplySettings = _reflection.GeneratedProtocolMessageType('ApplySettings', (_message.Message,), dict(
  DESCRIPTOR = _APPLYSETTINGS,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ApplySettings)
  ))
_sym_db.RegisterMessage(ApplySettings)

ChangePin = _reflection.GeneratedProtocolMessageType('ChangePin', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEPIN,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ChangePin)
  ))
_sym_db.RegisterMessage(ChangePin)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), dict(
  DESCRIPTOR = _PING,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Ping)
  ))
_sym_db.RegisterMessage(Ping)

Success = _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), dict(
  DESCRIPTOR = _SUCCESS,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Success)
  ))
_sym_db.RegisterMessage(Success)

Failure = _reflection.GeneratedProtocolMessageType('Failure', (_message.Message,), dict(
  DESCRIPTOR = _FAILURE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Failure)
  ))
_sym_db.RegisterMessage(Failure)

ButtonRequest = _reflection.GeneratedProtocolMessageType('ButtonRequest', (_message.Message,), dict(
  DESCRIPTOR = _BUTTONREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ButtonRequest)
  ))
_sym_db.RegisterMessage(ButtonRequest)

ButtonAck = _reflection.GeneratedProtocolMessageType('ButtonAck', (_message.Message,), dict(
  DESCRIPTOR = _BUTTONACK,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ButtonAck)
  ))
_sym_db.RegisterMessage(ButtonAck)

PinMatrixRequest = _reflection.GeneratedProtocolMessageType('PinMatrixRequest', (_message.Message,), dict(
  DESCRIPTOR = _PINMATRIXREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:PinMatrixRequest)
  ))
_sym_db.RegisterMessage(PinMatrixRequest)

PinMatrixAck = _reflection.GeneratedProtocolMessageType('PinMatrixAck', (_message.Message,), dict(
  DESCRIPTOR = _PINMATRIXACK,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:PinMatrixAck)
  ))
_sym_db.RegisterMessage(PinMatrixAck)

Cancel = _reflection.GeneratedProtocolMessageType('Cancel', (_message.Message,), dict(
  DESCRIPTOR = _CANCEL,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Cancel)
  ))
_sym_db.RegisterMessage(Cancel)

PassphraseRequest = _reflection.GeneratedProtocolMessageType('PassphraseRequest', (_message.Message,), dict(
  DESCRIPTOR = _PASSPHRASEREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:PassphraseRequest)
  ))
_sym_db.RegisterMessage(PassphraseRequest)

PassphraseAck = _reflection.GeneratedProtocolMessageType('PassphraseAck', (_message.Message,), dict(
  DESCRIPTOR = _PASSPHRASEACK,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:PassphraseAck)
  ))
_sym_db.RegisterMessage(PassphraseAck)

GetEntropy = _reflection.GeneratedProtocolMessageType('GetEntropy', (_message.Message,), dict(
  DESCRIPTOR = _GETENTROPY,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:GetEntropy)
  ))
_sym_db.RegisterMessage(GetEntropy)

Entropy = _reflection.GeneratedProtocolMessageType('Entropy', (_message.Message,), dict(
  DESCRIPTOR = _ENTROPY,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Entropy)
  ))
_sym_db.RegisterMessage(Entropy)

GetPublicKey = _reflection.GeneratedProtocolMessageType('GetPublicKey', (_message.Message,), dict(
  DESCRIPTOR = _GETPUBLICKEY,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:GetPublicKey)
  ))
_sym_db.RegisterMessage(GetPublicKey)

PublicKey = _reflection.GeneratedProtocolMessageType('PublicKey', (_message.Message,), dict(
  DESCRIPTOR = _PUBLICKEY,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:PublicKey)
  ))
_sym_db.RegisterMessage(PublicKey)

GetAddress = _reflection.GeneratedProtocolMessageType('GetAddress', (_message.Message,), dict(
  DESCRIPTOR = _GETADDRESS,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:GetAddress)
  ))
_sym_db.RegisterMessage(GetAddress)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESS,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:Address)
  ))
_sym_db.RegisterMessage(Address)

WipeDevice = _reflection.GeneratedProtocolMessageType('WipeDevice', (_message.Message,), dict(
  DESCRIPTOR = _WIPEDEVICE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:WipeDevice)
  ))
_sym_db.RegisterMessage(WipeDevice)

LoadDevice = _reflection.GeneratedProtocolMessageType('LoadDevice', (_message.Message,), dict(
  DESCRIPTOR = _LOADDEVICE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:LoadDevice)
  ))
_sym_db.RegisterMessage(LoadDevice)

ResetDevice = _reflection.GeneratedProtocolMessageType('ResetDevice', (_message.Message,), dict(
  DESCRIPTOR = _RESETDEVICE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:ResetDevice)
  ))
_sym_db.RegisterMessage(ResetDevice)

EntropyRequest = _reflection.GeneratedProtocolMessageType('EntropyRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENTROPYREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:EntropyRequest)
  ))
_sym_db.RegisterMessage(EntropyRequest)

EntropyAck = _reflection.GeneratedProtocolMessageType('EntropyAck', (_message.Message,), dict(
  DESCRIPTOR = _ENTROPYACK,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:EntropyAck)
  ))
_sym_db.RegisterMessage(EntropyAck)

RecoveryDevice = _reflection.GeneratedProtocolMessageType('RecoveryDevice', (_message.Message,), dict(
  DESCRIPTOR = _RECOVERYDEVICE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:RecoveryDevice)
  ))
_sym_db.RegisterMessage(RecoveryDevice)

WordRequest = _reflection.GeneratedProtocolMessageType('WordRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORDREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:WordRequest)
  ))
_sym_db.RegisterMessage(WordRequest)

WordAck = _reflection.GeneratedProtocolMessageType('WordAck', (_message.Message,), dict(
  DESCRIPTOR = _WORDACK,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:WordAck)
  ))
_sym_db.RegisterMessage(WordAck)

SignMessage = _reflection.GeneratedProtocolMessageType('SignMessage', (_message.Message,), dict(
  DESCRIPTOR = _SIGNMESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:SignMessage)
  ))
_sym_db.RegisterMessage(SignMessage)

VerifyMessage = _reflection.GeneratedProtocolMessageType('VerifyMessage', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYMESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:VerifyMessage)
  ))
_sym_db.RegisterMessage(VerifyMessage)

MessageSignature = _reflection.GeneratedProtocolMessageType('MessageSignature', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGESIGNATURE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:MessageSignature)
  ))
_sym_db.RegisterMessage(MessageSignature)

EncryptMessage = _reflection.GeneratedProtocolMessageType('EncryptMessage', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTMESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:EncryptMessage)
  ))
_sym_db.RegisterMessage(EncryptMessage)

EncryptedMessage = _reflection.GeneratedProtocolMessageType('EncryptedMessage', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTEDMESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:EncryptedMessage)
  ))
_sym_db.RegisterMessage(EncryptedMessage)

DecryptMessage = _reflection.GeneratedProtocolMessageType('DecryptMessage', (_message.Message,), dict(
  DESCRIPTOR = _DECRYPTMESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DecryptMessage)
  ))
_sym_db.RegisterMessage(DecryptMessage)

DecryptedMessage = _reflection.GeneratedProtocolMessageType('DecryptedMessage', (_message.Message,), dict(
  DESCRIPTOR = _DECRYPTEDMESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DecryptedMessage)
  ))
_sym_db.RegisterMessage(DecryptedMessage)

CipherKeyValue = _reflection.GeneratedProtocolMessageType('CipherKeyValue', (_message.Message,), dict(
  DESCRIPTOR = _CIPHERKEYVALUE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:CipherKeyValue)
  ))
_sym_db.RegisterMessage(CipherKeyValue)

CipheredKeyValue = _reflection.GeneratedProtocolMessageType('CipheredKeyValue', (_message.Message,), dict(
  DESCRIPTOR = _CIPHEREDKEYVALUE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:CipheredKeyValue)
  ))
_sym_db.RegisterMessage(CipheredKeyValue)

EstimateTxSize = _reflection.GeneratedProtocolMessageType('EstimateTxSize', (_message.Message,), dict(
  DESCRIPTOR = _ESTIMATETXSIZE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:EstimateTxSize)
  ))
_sym_db.RegisterMessage(EstimateTxSize)

TxSize = _reflection.GeneratedProtocolMessageType('TxSize', (_message.Message,), dict(
  DESCRIPTOR = _TXSIZE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:TxSize)
  ))
_sym_db.RegisterMessage(TxSize)

SignTx = _reflection.GeneratedProtocolMessageType('SignTx', (_message.Message,), dict(
  DESCRIPTOR = _SIGNTX,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:SignTx)
  ))
_sym_db.RegisterMessage(SignTx)

SimpleSignTx = _reflection.GeneratedProtocolMessageType('SimpleSignTx', (_message.Message,), dict(
  DESCRIPTOR = _SIMPLESIGNTX,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:SimpleSignTx)
  ))
_sym_db.RegisterMessage(SimpleSignTx)

TxRequest = _reflection.GeneratedProtocolMessageType('TxRequest', (_message.Message,), dict(
  DESCRIPTOR = _TXREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:TxRequest)
  ))
_sym_db.RegisterMessage(TxRequest)

TxAck = _reflection.GeneratedProtocolMessageType('TxAck', (_message.Message,), dict(
  DESCRIPTOR = _TXACK,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:TxAck)
  ))
_sym_db.RegisterMessage(TxAck)

SignIdentity = _reflection.GeneratedProtocolMessageType('SignIdentity', (_message.Message,), dict(
  DESCRIPTOR = _SIGNIDENTITY,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:SignIdentity)
  ))
_sym_db.RegisterMessage(SignIdentity)

SignedIdentity = _reflection.GeneratedProtocolMessageType('SignedIdentity', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDIDENTITY,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:SignedIdentity)
  ))
_sym_db.RegisterMessage(SignedIdentity)

FirmwareErase = _reflection.GeneratedProtocolMessageType('FirmwareErase', (_message.Message,), dict(
  DESCRIPTOR = _FIRMWAREERASE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:FirmwareErase)
  ))
_sym_db.RegisterMessage(FirmwareErase)

FirmwareUpload = _reflection.GeneratedProtocolMessageType('FirmwareUpload', (_message.Message,), dict(
  DESCRIPTOR = _FIRMWAREUPLOAD,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:FirmwareUpload)
  ))
_sym_db.RegisterMessage(FirmwareUpload)

DebugLinkDecision = _reflection.GeneratedProtocolMessageType('DebugLinkDecision', (_message.Message,), dict(
  DESCRIPTOR = _DEBUGLINKDECISION,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DebugLinkDecision)
  ))
_sym_db.RegisterMessage(DebugLinkDecision)

DebugLinkGetState = _reflection.GeneratedProtocolMessageType('DebugLinkGetState', (_message.Message,), dict(
  DESCRIPTOR = _DEBUGLINKGETSTATE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DebugLinkGetState)
  ))
_sym_db.RegisterMessage(DebugLinkGetState)

DebugLinkState = _reflection.GeneratedProtocolMessageType('DebugLinkState', (_message.Message,), dict(
  DESCRIPTOR = _DEBUGLINKSTATE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DebugLinkState)
  ))
_sym_db.RegisterMessage(DebugLinkState)

DebugLinkStop = _reflection.GeneratedProtocolMessageType('DebugLinkStop', (_message.Message,), dict(
  DESCRIPTOR = _DEBUGLINKSTOP,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DebugLinkStop)
  ))
_sym_db.RegisterMessage(DebugLinkStop)

DebugLinkLog = _reflection.GeneratedProtocolMessageType('DebugLinkLog', (_message.Message,), dict(
  DESCRIPTOR = _DEBUGLINKLOG,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:DebugLinkLog)
  ))
_sym_db.RegisterMessage(DebugLinkLog)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037com.satoshilabs.trezor.protobufB\rTrezorMessage'))
_MESSAGETYPE.values_by_name["MessageType_Initialize"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Initialize"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Ping"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Ping"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Success"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Success"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Failure"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Failure"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_ChangePin"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_ChangePin"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_WipeDevice"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_WipeDevice"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_FirmwareErase"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_FirmwareErase"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_FirmwareUpload"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_FirmwareUpload"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_GetEntropy"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_GetEntropy"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Entropy"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Entropy"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_GetPublicKey"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_GetPublicKey"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_PublicKey"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_PublicKey"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_LoadDevice"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_LoadDevice"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_ResetDevice"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_ResetDevice"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_SignTx"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_SignTx"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_SimpleSignTx"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_SimpleSignTx"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Features"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Features"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_PinMatrixRequest"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_PinMatrixRequest"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_PinMatrixAck"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_PinMatrixAck"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Cancel"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Cancel"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_TxRequest"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_TxRequest"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_TxAck"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_TxAck"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_CipherKeyValue"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_CipherKeyValue"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_ClearSession"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_ClearSession"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_ApplySettings"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_ApplySettings"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_ButtonRequest"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_ButtonRequest"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_ButtonAck"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_ButtonAck"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_GetAddress"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_GetAddress"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_Address"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_Address"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_EntropyRequest"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_EntropyRequest"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_EntropyAck"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_EntropyAck"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_SignMessage"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_SignMessage"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_VerifyMessage"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_VerifyMessage"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_MessageSignature"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_MessageSignature"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_PassphraseRequest"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_PassphraseRequest"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_PassphraseAck"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_PassphraseAck"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_EstimateTxSize"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_EstimateTxSize"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_TxSize"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_TxSize"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_RecoveryDevice"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_RecoveryDevice"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_WordRequest"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_WordRequest"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_WordAck"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_WordAck"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_CipheredKeyValue"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_CipheredKeyValue"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_EncryptMessage"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_EncryptMessage"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_EncryptedMessage"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_EncryptedMessage"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DecryptMessage"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DecryptMessage"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DecryptedMessage"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DecryptedMessage"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_SignIdentity"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_SignIdentity"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_SignedIdentity"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_SignedIdentity"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\230\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_GetFeatures"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_GetFeatures"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\220\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DebugLinkDecision"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DebugLinkDecision"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\240\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DebugLinkGetState"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DebugLinkGetState"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\240\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DebugLinkState"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DebugLinkState"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\250\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DebugLinkStop"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DebugLinkStop"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\240\265\030\001'))
_MESSAGETYPE.values_by_name["MessageType_DebugLinkLog"].has_options = True
_MESSAGETYPE.values_by_name["MessageType_DebugLinkLog"]._options = _descriptor._ParseOptions(descriptor_pb2.EnumValueOptions(), _b('\250\265\030\001'))
# @@protoc_insertion_point(module_scope)
